﻿using System;
using System.Collections.Generic;
using System.IO;

namespace OddsUS
{
    internal class Program
    {
        public static void Main(string[] args)
        {
            Console.WriteLine("Welcome to odds convert!");
            Console.WriteLine("Please enter decimal value, l to display the ladder, q to quit");
            var ladder = Getladder();
            do
            {
                var input = Console.ReadLine();
                if (string.IsNullOrEmpty(input))
                {
                    Console.WriteLine("Please enter decimal value, l to display the ladder, q to quit");
                } else if (input.Equals("q"))
                {
                    Console.WriteLine("Goodbye");
                    Environment.Exit(1);
                }
                else if (input.Equals("l"))
                {
                    Console.WriteLine(string.Join(", ", ladder));
                }
                else if (decimal.TryParse(input, out var oddsEu))
                {
                    var oddsUs = ConvertEuOddsToUs(oddsEu);
                    if (oddsUs.HasValue)
                    {
                        Console.WriteLine("EU " + oddsEu + " => US " + oddsUs.Value + " => Rounded US " +
                                          RoundUSOdds(oddsUs.Value, ladder));
                    }
                    else
                    {
                        Console.WriteLine("EU " + oddsEu + " => can not be convert to US odds");
                    }
                }
                else
                {
                    Console.WriteLine("Please enter decimal value, l to display the ladder, q to quit");
                }
            } while (true);
        }


        private static decimal? ConvertEuOddsToUs(decimal oddsEu)
        {
            decimal? oddUs;
            if (oddsEu == 1)
            {
                oddUs = null;
            }
            else if (oddsEu >= 2)
            {
                oddUs = (oddsEu - 1) * 100;
            }
            else
            {
                oddUs = (-100) / (oddsEu - 1);
            }

            return oddUs;
        }

        private static int RoundUSOdds(decimal oddsUs, List<int> ladder)
        {
            var min = Int32.MinValue;
            var max = Int32.MaxValue;
            ladder.ForEach(l =>
            {
                if (oddsUs >= l)
                {
                    min = l;
                }

                if (oddsUs <= l && l < max)
                {
                    max = l;
                }
            });

            return Math.Abs(oddsUs) - Math.Abs(min) <= Math.Abs(max) - Math.Abs(oddsUs) ? min : max;
        }

        private static List<int> Getladder()
        {
            using (var reader = new StreamReader(@"US Ladder - v2.csv"))
            {
                var ladder = new List<int>();

                while (!reader.EndOfStream)
                {
                    ladder.Add(Int32.Parse(reader.ReadLine()));
                }

                ladder.Sort();
                return ladder;
            }
        }
    }
}