const fs = require('fs');
const readline = require('readline'), rl = readline.createInterface(process.stdin, process.stdout);

console.log("Welcome to odds convert!");

const content = fs.readFileSync("US Ladder - v2.csv");
const ladder = content.toString().split('\n').map(line => parseInt(line));

const convertEuOddsToUs = (odds_eu) => {
    if (odds_eu === 1) {
        return null;
    } else if (odds_eu >= 2) {
        return (odds_eu - 1) * 100;
    } else {
        return -100 / (odds_eu - 1);
    }
};


const roundUSOdds = (odds_us, ladder) => {
    let max_ladder = Number.MAX_SAFE_INTEGER;
    let min_ladder = Number.MIN_SAFE_INTEGER;

    ladder.forEach(l => {
        if (odds_us >= l) {
            min_ladder = l;
        }
        if (odds_us <= l && l < max_ladder) {
            max_ladder = l
        }
    });

    return Math.abs(odds_us) - Math.abs(min_ladder) <= Math.abs(max_ladder) - Math.abs(odds_us) ? min_ladder : max_ladder;
};

rl.setPrompt('Please enter decimal value, l to display the ladder, q to quit > ');
rl.prompt();

rl.on('line', function(line) {
    switch(line.trim()) {
        case 'l':
            console.log(ladder.join(","));
            break;
        case 'q':
            rl.close();
            break;
        default:
            let oddsEU = parseFloat(line);
            let oddsUS = convertEuOddsToUs(oddsEU);
            if (oddsUS) {
                let oddsUSRounded = roundUSOdds(oddsUS.toFixed(5), ladder);
                console.log("EU "
                    + line
                    + " => US "
                    + oddsUS.toFixed(5)
                    + " => Rounded US "
                    + oddsUSRounded);
                break;
            } else {
                console.error("EU " + oddsEU + " => can not be convert to US odds")
            }
    }
    rl.prompt();
}).on('close', function() {
    console.log('Goodbye!');
    process.exit(0);
});